==> tuia-news-center-api-2.4.4.1-20190730.020403-3-sources.jar: cn/com/duiba/tuia/news/center/dto/weather/UserWeatherDto.java <==
package cn.com.duiba.tuia.news.center.dto.weather;

import java.io.Serializable;
import java.util.Date;

/**
 * 功能描述：
 *
 * @Auther: xiaotian
 * @Date: 2019/7/22 13:54
 * @Description:
 */
public class UserWeatherDto implements Serializable {

    private Long id;

    private Long userId;

    private String cityId;

    private Integer lastWeatherType;

    private Integer totalEnery;

    private Integer remainEnery;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getCityId() {
        return cityId;
    }

    public void setCityId(String cityId) {
        this.cityId = cityId == null ? null : cityId.trim();
    }

    public Integer getLastWeatherType() {
        return lastWeatherType;
    }

    public void setLastWeatherType(Integer lastWeatherType) {
        this.lastWeatherType = lastWeatherType;
    }

    public Integer getTotalEnery() {
        return totalEnery;
    }

    public void setTotalEnery(Integer totalEnery) {
        this.totalEnery = totalEnery;
    }

    public Integer getRemainEnery() {
        return remainEnery;
    }

    public void setRemainEnery(Integer remainEnery) {
        this.remainEnery = remainEnery;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}

==> tuia-news-center-api-2.9.0.0-20191014.111346-3-sources.jar: cn/com/duiba/tuia/news/center/dto/weather/UserWeatherDto.java <==
package cn.com.duiba.tuia.news.center.dto.weather;

import java.io.Serializable;
import java.util.Date;

/**
 * 功能描述：
 *
 * @Auther: xiaotian
 * @Date: 2019/7/22 13:54
 * @Description:
 */
public class UserWeatherDto implements Serializable {

    private Long id;

    private Long userId;

    private String cityId;

    private Integer lastWeatherType;

    private Integer totalEnery;

    private Integer remainEnery;

    private String rewardContent;

    private Date lastPickTime;

    private Date gmtCreate;

    private Date gmtModified;

    public String getRewardContent() {
        return rewardContent;
    }

    public void setRewardContent(String rewardContent) {
        this.rewardContent = rewardContent;
    }

    public Date getLastPickTime() {
        return lastPickTime;
    }

    public void setLastPickTime(Date lastPickTime) {
        this.lastPickTime = lastPickTime;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getCityId() {
        return cityId;
    }

    public void setCityId(String cityId) {
        this.cityId = cityId == null ? null : cityId.trim();
    }

    public Integer getLastWeatherType() {
        return lastWeatherType;
    }

    public void setLastWeatherType(Integer lastWeatherType) {
        this.lastWeatherType = lastWeatherType;
    }

    public Integer getTotalEnery() {
        return totalEnery;
    }

    public void setTotalEnery(Integer totalEnery) {
        this.totalEnery = totalEnery;
    }

    public Integer getRemainEnery() {
        return remainEnery;
    }

    public void setRemainEnery(Integer remainEnery) {
        this.remainEnery = remainEnery;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}
